'Bambino-08+
SERTXD("B08+",CR)    'report program number

#PicAxe 20M2
#no_data
'Bambino-01  Test eyeLEDs, whiskerLEDs and speaker
'Bambino-02  Test PWM of eyeLEDs
'Bambino-03  Test InfraRed input
'Bambino-04  Test Eye light values
'Bambino-05  Test Whisker light values
'Bambino-06  Play the inbuilt tunes using keys 1 to 4 and beep on 5
'Bambino-07  Set servos to mid position
'Bambino-08  Calibrate servo mid positions and put in EEPROM.
'Bambino-08+ Adjust servo mid positions from IR-Handset and put in EEPROM.

'-----------------------------------------------------------------
Rationale:
'This an easier way than Bambino-08 to do it.
'Studying the code will be useful for understanding later programs.
 
'Calibrate servo mid positions.
'-----------------------------
'The pulsout value must be between 100 and 200
'  otherwise the servo may be damaged.
'Because of the way each servo is made and
'  the horns can only be put on about every 15 degrees
'  the feet may not be exactly side by side or flat on the ground.
'You can use the infra-red-controller
'   to adjust and store the rollC and paceC positions.
'   press either the [left] or [right] keys to adjust the Roll servo,
'   press either the [forward] or [backward] keys to adjust the Pace servo,
'   for the Roll servo the right down LED will light
'   for the Pace servo the left down LED will light
'   press either the [+] or [-] keys to adjust the servo position
'   when it is right press the [Power] key,
'   the down LEDs will go out and the mouth LED will light
'   if you press other keys then the eyes will say no
'   adjust both servos.
'   The calibrated values are stored in EEPROM for further programs.
'Open a serial terminal @4800 to see the values

'=================================================================
'TVR010 PicAxe IR-controller - Setup
'-----------------------------------
'Before use, the transmitter must be programmed with the Sony transmit code.
'1. Insert 2 AAA size batteries, preferably alkaline.
'2. Press S and B at the same time. S is in the centre of the arrows.
'  The top left red LED should light.
'3. Press 0. The LED should flash.
'4. Press 1. The LED should flash.
'5. Press 3. The LED should go out.
'6. Press the red power button (top right).
'-----------------------------------------------------------------
'IRin cmnds PicAxe controller

SYMBOL KEY_POWER      = 21

SYMBOL KEY_UP         = 16
SYMBOL KEY_DOWN       = 17
SYMBOL KEY_RIGHT      = 18
SYMBOL KEY_LEFT       = 19

SYMBOL KEY_BAR        = 96
SYMBOL KEY_TENT       = 54
SYMBOL KEY_VERT_CROSS = 37    'use synonym for easier coding
SYMBOL KEY_VCROSS     = 37
SYMBOL KEY_DIAG_CROSS = 20    'use synonym for easier coding
SYMBOL KEY_XCROSS     = 20

SYMBOL IRkey1         =  0
SYMBOL IRkey2         =  1
SYMBOL IRkey3         =  2
SYMBOL IRkey4         =  3
SYMBOL IRkey5         =  4
SYMBOL IRkey6         =  5
SYMBOL IRkey7         =  6
SYMBOL IRkey8         =  7
SYMBOL IRkey9         =  8
SYMBOL KEY_MINUS      = 98
SYMBOL KEY_0          =  9    'QUIT command mode
SYMBOL KEY_PLUS       = 11
'=================================================================

SYMBOL servopace      =c.0  'left connector
SYMBOL servoroll      =c.4  'right connector
SYMBOL VoiceLed_      =c.5
SYMBOL eyeLedL_       =c.2    'low =>LED on
SYMBOL eyeLedR_       =b.1    'low =>LED on
SYMBOL GwhiskerLedL_  =c.3    'low =>Ground whisker LED on
SYMBOL GwhiskerLedR_  =b.3    'low =>Ground whisker LED on
SYMBOL eyeR           =c.7
SYMBOL eyeL           =c.1
SYMBOL iIRin          =c.6
SYMBOL oIRout         =b.2

SYMBOL temp0        =B0
SYMBOL cmnd         =B1
SYMBOL Scentre    =W1
SYMBOL  rollC       =B2
SYMBOL  paceC       =B3

'EEPROM DATA
SYMBOL DrollC =254
SYMBOL DpaceC =255


initialise:
  rollC      =150  'Default, 100 is roll to the left, 150 is nominal centre
  paceC      =150  'Default, 100 is left foot back,   150 is nominal centre
  'get values from EEPROM if set by program #8
  READ DrollC,temp0
  IF temp0>130 AND temp0<170 THEN  'only load valid values
    rollC =temp0
   ELSE
    WRITE DrollC,rollC             'save default for other programs
   ENDIF
  READ DpaceC,temp0
  IF temp0>130 AND temp0<170 THEN  'only load valid values
    paceC =temp0
   ELSE
    WRITE DpaceC,paceC             'save default  for other programs
   ENDIF
  SERTXD("rollC=",#rollC," paceC=",#paceC,CR)




START:
  TOGGLE VoiceLed_              'flash mouth so we know program is running
  GOSUB tellservos:
  IRIN [50,Start],iIRin,cmnd    'irin with timeout, no IR =>Start
  IF cmnd>=16 AND cmnd<=19 THEN adjust 'only if 16,17,18,19
  GOSUB badkey
  GOTO START

adjust:
  GOSUB beep50                  'so we know valid IR received
  IF cmnd=16 OR cmnd=17 THEN
    GOSUB adjustpaceC           '16,17
   ELSE
    GOSUB adjustrollC           '18,19
   ENDIF

adjustrollC:
  temp0 =DrollC
  LOW GwhiskerLedR_             'LED on, Right servo is Roll
  GOTO adjustC

adjustpaceC:
  temp0 =DpaceC
  LOW GwhiskerLedL_             'LED on, Left servo is Pace
'  GOTO _adjustC

adjustC:
waitIR:
  GOSUB tellservos:
  IRIN [50,waitIR],iIRin,cmnd   'irin with timeout, no IR =>_waitIR
  SELECT cmnd
    CASE KEY_POWER              'finished
      SELECT temp0
        CASE DrollC
          WRITE DrollC,rollC    'save for other programs
          HIGH  GwhiskerLedR_
        CASE DpaceC
          WRITE DpaceC,paceC    'save for other programs
          HIGH  GwhiskerLedL_
       ENDSELECT
      SERTXD("rollC=",#rollC," paceC=",#paceC,CR)
      GOTO START                'back to START
    CASE KEY_MINUS
      SELECT temp0
        CASE DrollC
          rollC =rollC -1
          SERTXD("rollC=",#rollC,CR)
        CASE DpaceC
          paceC =paceC -1
          SERTXD("paceC=",#paceC,CR)
       ENDSELECT
    CASE KEY_PLUS
      SELECT temp0
        CASE DrollC
          rollC =rollC +1
          SERTXD("rollC=",#rollC,CR)
        CASE DpaceC
          paceC =paceC +1
          SERTXD("paceC=",#paceC,CR)
       ENDSELECT
    ELSE
      GOSUB badkey
   ENDSELECT
  GOTO adjustC

'-----------------------------------------
tellservos:
  PULSOUT servopace,paceC    'pulse servo paceC
  PULSOUT servoroll,rollC    'pulse servo rollC
  PAUSE 20                   'pause 20ms
  RETURN

badkey:
  LOW eyeLedR_
  PAUSE 100
  HIGH eyeLedR_
  LOW eyeLedL_
  PAUSE 100
  HIGH eyeLedL_
  RETURN

beep50:
  SOUND VoiceLed_,(50,10)
  RETURN
'=================================================================
